OC.L10N.register(
    "core",
    {
    "Please select a file." : "Lütfen bir dosya seçin.",
    "File is too big" : "Dosya çok büyük",
    "The selected file is not an image." : "Seçilmiş dosya bir görsel dosyası değil.",
    "The selected file cannot be read." : "Seçilmiş dosya okunamadı.",
    "The file was uploaded" : "Dosya yüklendi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yüklenen dosya php.ini dosyasındaki yüklenebilecek dosya boyutunu belirten upload_max_filesize değişkeninin değerini aşıyor",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklenen dosya HTML formundaki yüklenebilecek dosya boyutunu belirten MAX_FILE_SIZE değişkeninin değerini aşıyor",
    "The file was only partially uploaded" : "Dosyanın yalnızca bir bölümü yüklendi",
    "No file was uploaded" : "Herhangi bir dosya yüklenmedi",
    "Missing a temporary folder" : "Bir geçici klasör eksik",
    "Could not write file to disk" : "Dosya diske yazılamadı",
    "A PHP extension stopped the file upload" : "Bir PHP eklentisi dosyanın yüklenmesini engelledi",
    "Invalid file provided" : "Belirtilen dosya geçersiz",
    "No image or file provided" : "Bir görsel ya da dosya belirtilmemiş",
    "Unknown filetype" : "Dosya türü bilinmiyor",
    "An error occurred. Please contact your admin." : "Bir sorun çıktı. Lütfen yöneticinizle görüşün.",
    "Invalid image" : "Görsel geçersiz",
    "No temporary profile picture available, try again" : "Kullanılabilecek geçici bir profil görseli bulunamadı. Yeniden deneyin",
    "No crop data provided" : "Kırpma verileri belirtilmemiş",
    "No valid crop data provided" : "Geçerli bir kırpma verisi belirtilmemiş",
    "Crop is not square" : "Kırpma kare şeklinde değil",
    "State token does not match" : "Durum kodu eşleşmiyor",
    "Invalid app password" : "Uygulama parolası geçersiz",
    "Could not complete login" : "Oturum açılamadı",
    "Your login token is invalid or has expired" : "Oturum açma kodunuz geçersiz ya da geçerlilik süresi dolmuş",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Bu Nextcloud topluluk sürümü desteklenmiyor ve anlık bildirimler sınırlı şekilde kullanılabiliyor.",
    "Login" : "Oturum aç",
    "Password reset is disabled" : "Parola sıfırlama devre dışı bırakılmış",
    "Could not reset password because the token is expired" : "Kodun geçerlilik süresi dolmuş olduğundan parola sıfırlanamadı",
    "Could not reset password because the token is invalid" : "Kod geçersiz olduğundan parola sıfırlanamadı",
    "%s password reset" : "%s parola sıfırlama",
    "Password reset" : "Parolamı sıfırla",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Parolanızı sıfırlamak için düğmeye tıklayın. Parola sıfırlama isteğinde bulunmadıysanız bu e-postayı yok sayabilirsiniz.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Parolanızı sıfırlamak için bağlantıya tıklayın. Parola sıfırlama isteğinde bulunmadıysanız bu e-postayı yok sayabilirsiniz.",
    "Reset your password" : "Parolamı sıfırla",
    "Nextcloud Server" : "Nextcloud sunucusu",
    "Some of your link shares have been removed" : "Bazı paylaşım bağlantılarınız silindi",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Bir güvenlik açığı nedeniyle bazı paylaşım bağlantılarınızı silmek zorunda kaldık. ayrıntılı bilgi almak için bağlantıya bakabilirsiniz.",
    "The user limit of this instance is reached." : "Bu kopya için kullanıcı sayısı sınırına ulaşıldı.",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Kullanıcı sayısı sınırını artırmak için destek uygulamasına abonelik anahtarınızı yazın. Bu ayrıca size Nextcloud Enterprise sürümünün sunduğu ve kurumsal operasyonlar için önemle önerilen tüm ek avantajları sağlar.",
    "Learn more ↗" : "Ayrıntılı bilgi alın ↗",
    "Preparing update" : "Güncelleme hazırlanıyor",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Onarım adımı:",
    "Repair info:" : "Onarım bilgileri:",
    "Repair warning:" : "Onarım uyarısı:",
    "Repair error:" : "Onarım sorunu:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Otomatik güncellemeler config.php dosyasında devre dışı bırakılmış olduğundan, komut satırı güncelleyicisini kullanın.",
    "Turned on maintenance mode" : "Bakım kipi etkinleştirildi",
    "Turned off maintenance mode" : "Bakım kipi devre dışı bırakıldı",
    "Maintenance mode is kept active" : "Bakım kipi etkin tutuldu",
    "Updating database schema" : "Veritabanı şeması güncelleniyor",
    "Updated database" : "Veritabanı güncellendi",
    "Update app \"%s\" from App Store" : "Uygulama mağazasından \"%s\" uygulamasını güncelle",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s için veritabanı şeması güncellemesi denetleniyor (veritabanının büyüklüğüne bağlı olarak uzun sürebilir)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\", %2$s sürümüne güncellendi",
    "Set log level to debug" : "Günlükleme düzeyini Hata Ayıklama olarak ayarla",
    "Reset log level" : "Günlükleme düzeyini sıfırla",
    "Starting code integrity check" : "Kod bütünlük sınaması başlatılıyor",
    "Finished code integrity check" : "Kod bütünlük sınaması bitti",
    "%s (incompatible)" : "%s (uyumsuz)",
    "The following apps have been disabled: %s" : "Şu uygulamalar devre dışı bırakıldı: %s",
    "Already up to date" : "Zaten güncel",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Web sunucunuz dosya eşitlemesi için doğru şekilde ayarlanmamış. WebDAV arabirimi sorunlu görünüyor.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Web sunucunuz \"{url}\" adresini çözümleyebilmesi için doğru şekilde ayarlanmamış. Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Web sunucunuz \"{url}\" adresini doğru olarak çözümleyecek şekilde yapılandırılmamış. Bu sorun genellikle web sunucu yapılandırmasının bu klasörü doğrudan aktaracak şekilde güncellenmemiş olmasından kaynaklanır. Lütfen kendi yapılandırmanızı, Apache için uygulama ile gelen \".htaccess\" dosyasındaki rewrite komutları ile ya da Nginx için {linkstart}belgeler ↗{linkend} bölümünde bulunan ayarlar ile karşılaştırın. Nginx üzerinde genellikle \"location ~\" ile başlayan satırların güncellenmesi gerekir.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Web sunucunuz .woff2 dosyalarını aktaracak şekilde yapılandırılmamış. Bu sık karşılaşılan bir Nginx yapılandırma sorunudur. Nextcloud 15 için .woff2 dosyalarını da aktaracak ek bir ayar yapılması gereklidir. Kullandığınız Nginx yapılandırmasını {linkstart}belgeler ↗{linkend} bölümünde bulunan önerilen yapılandırma dosyası ile karşılaştırın.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP yanlış kurulmuş ve sistem ortam değişkenlerini okuyamıyor gibi görünüyor. getenv(\"PATH\") komutu ile yapılan sınama sonucunda boş bir yanıt alındı.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Lütfen PHP yapılandırma notları ve özellikle php-fpm kullanırken sunucunuzdaki PHP yapılandırması için {linkstart}kurulum belgeleri ↗{linkend} bölümüne bakabilirsiniz.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Salt okunur yapılandırma etkinleştirilmiş. Bu yapılandırma, bazı ayarların web arayüzünden yapılmasını önler. Ayrıca, bu dosyanın her güncelleme öncesinde el ile yazılabilir yapılması gerekir.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "E-posta sunucusu yapılandırmanızı henüz ayarlamadınız veya doğrulamadınız. Ayarları yapmak için {mailSettingsStart}Temel ayarla {mailSettingsEnd} bölümüne gidin. Ardından, ayarlarınızı doğrulamak için formun altındaki \"E-posta gönder\" düğmesine tıklayın.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Veritabanınız \"READ COMMITTED\" işlem yalıtma düzeyinde çalışmıyor. Bu durum aynı anda birden çok işlem yapıldığında sorun çıkmasına yol açabilir.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP \"fileinfo\" modülü bulunamadı. MIME türü algılamasında en iyi sonuçları elde etmek için bu modülü etkinleştirmeniz önerilir.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "İşlemsel dosya kilidi devre dışı. Bu durum yarış koşullarında (race condition) sorun çıkarabilir. Bu sorunlardan kaçınmak için config.php dosyasındaki \"filelocking.enabled\" seçeneğini etkinleştirin. Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Lütfen config.php dosyanızdaki \"overwrite.cli.url\" seçeneğini, kullanıcılarınızın bu Nextcloud kopyasına erişmek için kullandığı adres olarak ayarladığınızdan emin olun. Öneri: \"{suggestedOverwriteCliURL}\". Yoksa, cron üzerinden aders oluşturma sorunları çıkabilir. (Önerilen adres, kullanıcılarınızın bu Nextcloud kopyasına erişmek için kullandığı adres olmasa da olabilir. Her durumda bunu iki kez denetlemek iyi olur.)",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Kurulumunuz için bir varsayılan telefon bölgesi ayarlanmamış. Bu bölge telefon numaralarının bir ülke kodu belirtilmeden doğrulanmasını sağlar. Telefon numaralarının ülke kodu olmadan yazılabilmesini istiyorsanız, yapılandırma dosyasına \"default_phone_region\" seçeneğini ekleyerek ilgili {linkstart}ISO 3166-1 ↗{linkend} bölge kodunu yazın.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Zamanlanmış görev CLI üzerinden çalıştırılamadı. Şu teknik sorunlar çıktı:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Görev arka planda son olarak {relativeTime} zamanında yürütülmüş. Bir şeyler yanlış görünüyor. {linkstart}Arka plan görevi ayarlarını gözden geçirin ↗{linkend}.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Bu Nextcloud topluluk sürümü desteklenmiyor. Bu kopyanın boyutu göz önüne alındığında, başarım, güvenilirlik ve ölçeklenebilirlik garanti edilemez. Ücretsiz hizmetimizi aşırı yüklememek için anında bildirimler sınırlandı. {linkstart}https://nextcloud.com/enterprise{linkend} adresinden Nextcloud Enterprise sürümünün avantajları hakkında ayrıntılı bilgi alabilirsiniz.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Bu sunucunun çalışan bir İnternet bağlantısı yok. Birden çok uç noktaya erişilemez. Bu durumda dış depolama alanı bağlama, güncelleme bildirimleri ya da üçüncü taraf uygulamalarını kurmak gibi bazı özellikler çalışmaz. Dosyalara uzaktan erişim ve bildirim e-postalarının gönderilmesi işlemleri de yapılamaz. Tüm bu özelliklerin kullanılabilmesi için sunucuyu İnternet üzerine bağlamanız önerilir.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Henüz bir ön bellek yapılandırılmamış. Olabiliyorsa başarımı arttırmak için memcache ön bellek ayarlarını yapın. Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Güvenlik nedeniyle kullanılması önemle önerilen rastgelelik kaynağı PHP tarafından bulunamıyor. Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Şu anda PHP {version} sürümünü kullanıyorsunuz. Kullandığınız dağıtım desteklediği zaman PHP sürümünüzü güncelleyerek {linkstart}PHP grubu tarafından sağlanan başarım ve güvenlik geliştirmelerinden ↗{linkend} faydalanın.",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 PHP 7.3 sürümünü destekleyen son sürümdür. Nextcloud 24 sürümü için en az PHP 7.4 gereklidir.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ters vekil sunucu üst bilgi yapılandırmanız doğru değil ya da Nextcloud üzerine güvenilen bir vekil sunucudan erişiyorsunuz. Böyle değil ise bu bir güvenlik sorunudur ve bir saldırganın IP adresini Nextcolud sunucusuna farklı göstermesine izin verebilir. Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached dağıtık bellek olarak yapılandırılmış ancak kurulmuş PHP \"memcache\" modülü yanlış. \\OC\\Memcache\\Memcached yalnızca \"memcache\" modülünü değil \"memcached\" mdoülünü destekler. İki modül hakkında ayrıntılı bilgi almak için {linkstart}Memcached Wiki sayfasına ↗{linkend} bakabilirsiniz.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Bazı dosyalar bütünlük denetiminden geçemedi. Bu sorunun çözümü ile ilgili bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz. ({linkstart}Geçersiz dosyaların listesi…{linkend}  / {linkstart}Yeniden Tara…{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcache modülü düzgün yapılandırılmamış. Ayrıntılı bilgi almak için {linkstart}belgelere ↗{linkend} bakın.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "\"set_time_limit\" PHP işlevi kullanılamıyor. Bu durum betiklerin yürütme sırasında durmasına, ve kurulumunuzun çalışmamasına neden olabilir. Bu işlevin etkinleştirilmesi önemle önerilir.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP kurulumunuzda FreeType desteği yok. Bu durum profil görsellerinin ve ayarlar bölümünün bozuk görüntülenmesine neden olur.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "\"{tableName}\" tablosundaki \"{indexName}\" dizini eksik.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Veritabanında bazı dizinler eksik. Büyük tablolara dizinlerin eklenmesi uzun sürebildiğinden bu işlem otomatik olarak yapılmaz. Sunucunuz normal çalışırken eksik dizinleri el ile eklemek için \"occ db:add-missing-indices\" komutunu yürütün. Dizinler eklendikten sonra bu tablolar üzerindeki sorgular çok daha hızlı yürütülür.",
    "Missing primary key on table \"{tableName}\"." : "\"{tableName}\" tablosunda birincil dizin anahtarı eksik.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Veritabanında bazı birincil dizin anahtarları eksik. Büyük tablolara birincil anahtarların eklenmesi uzun sürebildiğinden bu işlem otomatik olarak yapılmaz. Sunucunuz normal çalışırken eksik birincil anahtarları el ile eklemek için \"occ db:add-missing-primary-keys\" komutunu yürütün.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "\"{tableName}\" tablosundaki isteğe bağlı \"{coumnName}\" sütunu eksik.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Veritabanında bazı isteğe bağlı sütunlar eksik. Büyük tablolara sütunların eklenmesi uzun sürebildiğinden, sütunlar isteğe bağlı olduğunda bu işlem otomatik olarak yapılmaz. Sunucunuz normal çalışırken eksik sütunları el ile eklemek için \"occ db:add-missing-columns\" komutunu yürütün. Sütunlar eklendikten sonra bazı özelliklerin yanıtı ya da kullanımı daha iyileşebilir.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Bu kopyada önerilen bazı PHP modülleri eksik. Daha iyi başarım ve uyumluluk için bu modüllerin kurulması önemle önerilir.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Tema uygulamasında olmasına rağmen \"imagick\" PHP modülü etkinleştirilmemiş. Favicon oluşturma işleminin doğru çalışması için bu modülü kurmanız ve etkinleştirmeniz gerekir.",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "\"gmp\" ve/veya \"bcmath\" PHP modülleri etkinleştirilmemiş. WebAuthn parolasız kimlik doğrulaması kullanıyorsanız, bu modüller gereklidir.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Bu kopyadaki php-imagick modülünde SVG desteği yok. Daha iyi başarım ve uyumluluk için bu modülün kurulması önemle önerilir.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Veritabanında büyük tamsayıya dönüştürülecek bazı sütunlar eksik. Sütun türlerini büyük tablolara dönüştürme işlemi uzun sürebileceğinden bu işlem otomatik olarak yapılmaz. Sunucunuz normal çalışırken bekleyen değişiklikleri el ile uygulamak için \"occ db:convert-filecache-bigint\" komutunu yürütün. Bu işlem yapılırken Nextcloud kopyası çevrimdışı olur. Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Şu anda veritabanı olarak SQLite kullanılıyor. Daha büyük kurulumlar için farklı bir veritabanı arka ucuna geçmenizi öneriyoruz.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Özellikle dosya eşitleme için masaüstü istemcisi kullanılırken SQLite kullanımı önerilmez.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Başka bir veritabanına geçmek için komut satırı aracını kullanın: \"occ db:convert-type\" ya da {linkstart}belgeler ↗{linkend} bölümüne bakın.",
    "The PHP memory limit is below the recommended value of 512MB." : "PHP bellek sınırı önerilen 512 MB değerinden küçük.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Bazı uygulama klasörlerinin sahipliği web sunucusunun kullandığından başka bir kullanıcıya ait. Bu durum, uygulamalar el ile kurulduğunda ortaya çıkabilir. Şu uygulama klasörlerinin izinlerini denetleyin:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Veritabanı olarak MySQL kullanılır ancak 4 bayt uzunluğundaki karakterleri desteklemez. 4 bayt uzunluğundaki karaktelerin (emjo simgeleri gibi) dosya adları ya da yorumlarda sorun çıkmadan işlenebilmesi için MySQL üzerinde 4 bayt desteğinin etkinleştirilmesi önerilir. Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Bu kopya, birincil depolama olarak S3 tabanlı bir nesne deposu kullanıyor. Yüklenen dosyalar geçici olarak sunucuya kaydedildiğinden PHP geçici klasöründe 50 GB boş alan bulunması önerilir. Klasör yolu ve kullanılabilecek alan hakkındaki ayrıntılı bilgi almak için günlüklere bakabilirsiniz. Bu durumu düzeltmek için php.ini içindeki geçici klasör yolunu değiştirin ya da kullanılan geçici klasörde daha fazla yer açın.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Bu kopyanın geçici klasörü, var olmayan veya yazılabilir olmayan bir klasörü gösteriyor.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Kopyanıza güvenli bir bağlantı üzerinden erişiyorsunuz. Bununla birlikte kopyanız güvenli olmayan adresler üretiyor. Bu durum genellikle bir ters vekil sunucunun arkasında bulunmanız nedeniyle düzgün ayarlanmamış yapılandırma değişkenlerinin değiştirilmesinden kaynaklanır. Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
    "Error occurred while checking server setup" : "Sunucu ayarları denetlenirken sorun çıktı",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Veri klasörünüz ve dosyalarınız İnternet üzerinden erişime açık olabilir. .htaccess dosyası çalışmıyor. Web sunucunuzu yapılandırarak veri klasörüne erişimi engellemeniz ya da veri klasörünü web sunucu kök klasörü dışına taşımanız önemle önerilir.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP üst bilgisi \"{expected}\" şeklinde ayarlanmamış. Bu durum olası bir güvenlik ya da gizlilik riski oluşturduğundan bu ayarın belirtildiği gibi yapılması önerilir.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP üst bilgisi \"{expected}\" şeklinde ayarlanmamış. Bu durum bazı özelliklerin düzgün çalışmasını engelleyebileceğinden bu ayarın belirtildiği gibi yapılması önerilir.",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP üst bilgisinde \"{expected}\" bulunmuyor. Bu durum olası bir güvenlik ya da gizlilik riski oluşturduğundan bu ayarın uygun şekilde yapılması önerilir.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "\"{header}\" HTTP üst bilgisi \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" ya da \"{val5}\" olarak ayarlanmamış. Bu durum yönlendiren bilgilerinin sızmasına neden olabilir. Ayrıntılı bilgi almak için {linkstart}W3C Önerilerine ↗{linkend} bakabilirsiniz.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "\"Strict-Transport-Security\" HTTP üst bilgisi en azından\"{seconds}\" saniyedir ayarlanmamış. Gelişmiş güvenlik sağlamak için {linkstart}güvenlik ipuçları ↗{linkend} bölümünde anlatıldığı şekilde HSTS özelliğinin etkinleştirilmesi önerilir.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Siteye HTTP üzerinden güvenli olmayan bağlantı ile erişiliyor. Sunucunuzu {linkstart}güvenlik ipuçları ↗{linkend} bölümünde anlatıldığı şekilde HTTPS kullanacak şekilde yapılandırmanız önemle önerilir.",
    "unknown text" : "bilinmeyen metin",
    "Hello world!" : "Merhaba dünya!",
    "sunny" : "güneşli",
    "Hello {name}, the weather is {weather}" : "Merhaba {name}, hava durumu {weather}",
    "Hello {name}" : "Merhaba {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Arama sonuçlarınız<script>alert(1)</script></strong>",
    "new" : "yeni",
    "_download %n file_::_download %n files_" : ["%n dosyayı indir","%n dosyayı indir"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Güncelleniyor. Bu sayfadan ayrılırsanız bazı işlemler yarım kalabilir.",
    "Update to {version}" : "{version} sürümüne güncelle",
    "An error occurred." : "Bir sorun çıktı.",
    "Please reload the page." : "Lütfen sayfayı yeniden yükleyin.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uygulama güncellenemedi. Ayrıntılı bilgi almak için bu sorun ile ilgili <a href=\"{url}\">forum iletimize</a> bakabilirsiniz.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uygulama güncellenemedi. Lütfen bu sorunu  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud topluluğuna</a> bildirin.",
    "Continue to {productName}" : "{productName} ile ilerle",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uygulama güncellendi. %n saniye içinde {productName} üzerine yönlendirileceksiniz.","Uygulama güncellendi. %n saniye içinde {productName} üzerine yönlendirileceksiniz."],
    "More apps" : "Diğer uygulamalar",
    "Currently open" : "Şu anda açık",
    "_{count} notification_::_{count} notifications_" : ["{count} bildirim","{count} bildirim"],
    "Log in" : "Oturum aç",
    "Logging in …" : "Oturum açılıyor …",
    "Server side authentication failed!" : "Kimlik sunucu tarafında doğrulanamadı!",
    "Please contact your administrator." : "Lütfen BT yöneticiniz ile görüşün.",
    "An internal error occurred." : "İçeride bir sorun çıktı.",
    "Please try again or contact your administrator." : "Lütfen yeniden deneyin ya da BT yöneticinizle görüşün.",
    "Log in to {productName}" : "{productName} oturumu aç",
    "Account name or email" : "Hesap ado ya da e-posta adresi",
    "Password" : "Parola",
    "Wrong username or password." : "Kullanıcı adı ya da parola hatalı.",
    "User disabled" : "Kullanıcı devre dışı",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "IP adresinizden yapılan birden çok geçersiz oturum açma girişimi algılandı. Bu nedenle oturum açmanız 30 saniye süreyle engellendi.",
    "Username or email" : "Kullanıcı adı ya da e-posta",
    "Your account is not setup for passwordless login." : "Hesabınız parola kullanmadan oturum açılacak şekilde ayarlanmamış.",
    "Browser not supported" : "Tarayıcı desteklenmiyor!",
    "Passwordless authentication is not supported in your browser." : "Parolasız kimlik doğrulama özelliği web tarayıcınız tarafından desteklenmiyor.",
    "Your connection is not secure" : "Bağlantınız güvenli değil",
    "Passwordless authentication is only available over a secure connection." : "Parolasız kimlik doğrulama özelliği yalnızca güvenli bir bağlantı üzerinden kullanılabilir.",
    "Reset password" : "Parolayı sıfırla",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Bu hesabın e-posta adresine bir parola sıfırlama iletisi gönderildi. Bir e-posta almazsanız gelen kutunuzdaki spam/gereksiz klasörlerine bakın ya da yardım almak için BT yöneticinizle görüşün.",
    "If it is not there ask your local administrator." : "E-postayı göremiyorsanız yerel BT yöneticinizle görüşün.",
    "Couldn't send reset email. Please contact your administrator." : "Sıfırlama e-postası gönderilemedi. Lütfen BT yöneticiniz ile görüşün.",
    "Password cannot be changed. Please contact your administrator." : "Parola değiştirilemedi. Lütfen BT yöneticiniz ile görüşün.",
    "Back to login" : "Oturum açmaya geri dön",
    "New password" : "Yeni parola",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Dosyalarınız şifrelendi. Parolanız sıfırlandıktan sonra verilerinizi geri almanın herhangi bir yolu olmayacak. Ne yapacağınızı bilmiyorsanız işlemi sürdürmeden önce BT yöneticiniz ile görüşün. İşlemi sürdürmek istediğinize emin misiniz? ",
    "I know what I'm doing" : "Ne yaptığımı biliyorum",
    "Resetting password" : "Parola sıfırlanıyor",
    "Recommended apps" : "Önerilen uygulamalar",
    "Loading apps …" : "Uygulamalar yükleniyor …",
    "Could not fetch list of apps from the App Store." : "Uygulama mağazasından uygulama listesi alınamadı.",
    "Installing apps …" : "Uygulamalar kuruluyor …",
    "App download or installation failed" : "Uygulama indirilemedi ya da kurulamadı",
    "Cannot install this app because it is not compatible" : "Bu uygulama uyumlu olmadığından kurulamadı",
    "Cannot install this app" : "Bu uygulama kurulamadı",
    "Skip" : "Atla",
    "Install recommended apps" : "Önerilen uygulamaları kur",
    "Schedule work & meetings, synced with all your devices." : "İşlerinizi ve toplantılarınızı planlayın ve tüm aygıtlarınızla eşitleyin.",
    "Keep your colleagues and friends in one place without leaking their private info." : "İş arkadaşlarınızın ve tanıdıklarınızın kayıtlarını kişisel bilgilerini sızdırmadan tek bir yerde tutun.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Dosyalar, Kişiler ve Takvim uygulamaları ile bir arada çalışan basit bir e-posta uygulaması.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Sohbet, görüntülü çağrı, ekran paylaşımı, çevrimiçi toplantılar ve web görüşmeleri - masaüstü ve mobil için uygulamalar.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collabora Online üzerinde hazırlanmış işbirlikli çalışma belgeleri, hesap tabloları ve sunumlar.",
    "Forgot password?" : "Parolamı unuttum",
    "Log in with a device" : "Bir aygıt ile oturum açın",
    "Back" : "Geri",
    "Login form is disabled." : "Oturum açma formu devre dışı bırakılmış.",
    "Edit Profile" : "Profili düzenle",
    "The headline and about sections will show up here" : "Başlık ve hakkında bölümleri burada görüntülenir",
    "You have not added any info yet" : "Henüz herhangi bir bilgi eklememişsiniz",
    "{user} has not added any info yet" : "{user} henüz herhangi bir bilgi eklememiş",
    "Error opening the user status modal, try hard refreshing the page" : "Üste açılan kullanıcı durumu penceresinde sorun çıktı. Sayfası temizleyerek yenilemeyi deneyin ",
    "Search starts once you start typing" : "Yazmaya başladığınızda arama yapılır",
    "Reset search" : "Aramayı sıfırla",
    "Start search" : "Aramayı başlat",
    "Search for {name} only" : "Yalnızca {name} için aransın",
    "No results for {query}" : "{query} sorgusundan bir sonuç alınamadı",
    "Press enter to start searching" : "Aramayı başlatmak için Enter tuşuna basın",
    "Start typing to search" : "Aramak için yazmaya başlayın",
    "Loading more results …" : "Diğer sonuçlar yükleniyor…",
    "Load more results" : "Diğer sonuçları yükle",
    "Search" : "Arama",
    "An error occurred while searching for {type}" : "{type} aranırken bir sorun çıktı",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Lütfen aramak için en az {minSearchLength} karakter yazın","Lütfen aramak için en az {minSearchLength} karakter yazın"],
    "This browser is not supported" : "Bu tarayıcı desteklenmiyor",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Web tarayıcınız desteklenmiyor. Lütfen daha yeni bir sürüme ya da desteklenen bir sürüme yükseltin.",
    "Continue with this unsupported browser" : "Bu desteklenmeyen web tarayıcı ile ilerle",
    "Supported versions" : "Desteklenen sürümler",
    "{name} version {version} and above" : "{name} {version} üzeri sürümler",
    "Search {types} …" : "{types} arama…",
    "Settings" : "Ayarlar",
    "Could not load your contacts" : "Kişileriniz yüklenemedi",
    "Search contacts …" : "Kişi arama …",
    "No contacts found" : "Herhangi bir kişi bulunamadı",
    "Show all contacts …" : "Tüm kişileri görüntüle …",
    "Install the Contacts app" : "Kişiler uygulamasını kur",
    "Loading your contacts …" : "Kişileriniz yükleniyor …",
    "Looking for {term} …" : "{term} ifadesi aranıyor …",
    "No" : "Hayır",
    "Yes" : "Evet",
    "No files in here" : "Burada herhangi bir dosya yok",
    "New folder" : "Yeni klasör",
    "No more subfolders in here" : "Burada başka bir alt klasör yok",
    "Name" : "Ad",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme",
    "\"{name}\" is an invalid file name." : "\"{name}\" dosya adı geçersiz.",
    "File name cannot be empty." : "Dosya adı boş olamaz.",
    "\"/\" is not allowed inside a file name." : "Dosya adında \"/\" kullanılamaz.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" dosya türüne izin verilmiyor",
    "{newName} already exists" : "{newName} zaten var",
    "Choose" : "Seçin",
    "Copy" : "Kopyala",
    "Move" : "Taşı",
    "Error loading file picker template: {error}" : "Dosya seçme kalıbı yüklenirken sorun çıktı: {error}",
    "OK" : "Tamam",
    "Error loading message template: {error}" : "İleti kalıbı yüklenirken sorun çıktı: {error}",
    "read-only" : "salt okunur",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} dosya çakışması","{count} dosya çakışması"],
    "One file conflict" : "Bir dosya çakışması",
    "New Files" : "Yeni dosyalar",
    "Already existing files" : "Zaten var olan dosyalar",
    "Which files do you want to keep?" : "Hangi dosyaları saklamak istiyorsunuz?",
    "If you select both versions, the copied file will have a number added to its name." : "İki sürümü de seçerseniz, kopyalanan dosyanın adına bir sayı eklenir.",
    "Cancel" : "İptal",
    "Continue" : "Sürdür",
    "(all selected)" : "(tüm seçilmişler)",
    "({count} selected)" : "({count} seçilmiş)",
    "Error loading file exists template" : "Dosya var kalıbı yüklenirken sorun çıktı",
    "Show list view" : "Liste görünümüne geç",
    "Show grid view" : "Tablo görünümüne geç",
    "Pending" : "Bekliyor",
    "Copy to {folder}" : "{folder} klasörüne kopyala",
    "Move to {folder}" : "{folder} Klasörüne Taşı",
    "Saving …" : "Kaydediliyor …",
    "Authentication required" : "Kimlik doğrulaması gerekli",
    "This action requires you to confirm your password" : "Bu işlemi yapabilmek için parolanızı yazmalısınız",
    "Confirm" : "Onayla",
    "Failed to authenticate, try again" : "Kimlik doğrulanamadı, yeniden deneyin",
    "seconds ago" : "saniyeler önce",
    "Connection to server lost" : "Sunucu bağlantısı kesildi",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Sayfa yüklenirken bir sorun çıktı. %n saniye sonra yeniden yüklenecek","Sayfa yüklenirken bir sorun çıktı. %n saniye sonra yeniden yüklenecek"],
    "Add to a project" : "Bir projeye ekle",
    "Show details" : "Ayrıntılar görüntülensin",
    "Hide details" : "Ayrıntılar gizlensin",
    "Rename project" : "Projeyi yeniden adlandır",
    "Failed to rename the project" : "Proje yeniden adlandırılamadı",
    "Failed to create a project" : "Bir proje eklenemedi",
    "Failed to add the item to the project" : "Öge projeye eklenemedi",
    "Connect items to a project to make them easier to find" : "Ögeleri bir projeye bağlayarak bulunmasını kolaylaştırın",
    "Type to search for existing projects" : "Var olan projeleri aramak için yazın",
    "New in" : "Şuraya ekle",
    "View changelog" : "Değişiklik günlüğünü görüntüle",
    "Very weak password" : "Parola çok zayıf",
    "Weak password" : "Parola zayıf",
    "So-so password" : "Parola idare eder",
    "Good password" : "Parola iyi",
    "Strong password" : "Parola güçlü",
    "No action available" : "Yapılabilecek bir işlem yok",
    "Error fetching contact actions" : "Kişi işlemleri alınırken sorun çıktı",
    "Non-existing tag #{tag}" : "#{tag} etiketi bulunamadı",
    "Restricted" : "Kısıtlı",
    "Invisible" : "Görünmez",
    "Delete" : "Sil",
    "Rename" : "Yeniden adlandır",
    "Collaborative tags" : "İşbirliği etiketleri",
    "No tags found" : "Herhangi bir etiket bulunamadı",
    "Personal" : "Kişisel",
    "Users" : "Kullanıcılar",
    "Apps" : "Uygulamalar",
    "Admin" : "Yönetici",
    "Help" : "Yardım",
    "Access forbidden" : "Erişim engellendi",
    "Profile not found" : "Profil bulunamadı",
    "The profile does not exist." : "Profil bulunamadı.",
    "Back to %s" : "%s sayfasına dön",
    "Page not found" : "Sayfa bulunamadı",
    "The page could not be found on the server." : "Sayfa sunucuda bulunamadı.",
    "Too many requests" : "Çok fazla istekte bulunuldu",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ağınızdan çok fazla istekte bulunuldu. Bir süre sonra yeniden deneyin ya da bir sorun olduğunu düşünüyorsanız BT yöneticiniz ile görüşün.",
    "Error" : "Hata",
    "Previous" : "Önceki",
    "Internal Server Error" : "Sunucuda bir sorun çıktı",
    "The server was unable to complete your request." : "Sunucu isteğinizi yerine getiremedi.",
    "If this happens again, please send the technical details below to the server administrator." : "Bu sorun sürerse lütfen aşağıdaki teknik ayrıntıları BT yöneticinize iletin.",
    "More details can be found in the server log." : "Sunucu günlüğünden ayrıntılı bilgi alabilirsiniz.",
    "Technical details" : "Teknik ayrıntılar",
    "Remote Address: %s" : "Uzak adres: %s",
    "Request ID: %s" : "İstek kodu: %s",
    "Type: %s" : "Tür: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "İleti: %s",
    "File: %s" : "Dosya: %s",
    "Line: %s" : "Satır: %s",
    "Trace" : "İz",
    "Security warning" : "Güvenlik uyarısı",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess dosyası yürürlükte olmadığından veri klasörünüz ve dosyalarınız İnternet üzerinden erişime açık.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Sunucunuzu nasıl yapılandıracağınız hakkında bilgi almak için <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">belgelere</a> bakabilirsiniz.",
    "Create an <strong>admin account</strong>" : "Bir <strong>yönetici hesabı</strong> oluşturun",
    "Username" : "Kullanıcı adı",
    "Show password" : "Parolayı görüntüle",
    "Toggle password visibility" : "Parolanın görünürlüğünü değiştir",
    "Storage & database" : "Depolama ve veritabanı",
    "Data folder" : "Veri klasörü",
    "Configure the database" : "Veritabanını yapılandır",
    "Only %s is available." : "Yalnızca %s kullanılabilir.",
    "Install and activate additional PHP modules to choose other database types." : "Diğer veritabanı türlerini seçebilmek için ek PHP modüllerini kurun ve etkinleştirin.",
    "For more details check out the documentation." : "Ayrıntılı bilgi almak için belgelere bakabilirsiniz.",
    "Database user" : "Veritabanı kullanıcı adı",
    "Database password" : "Veritabanı parolası",
    "Database name" : "Veritabanı adı",
    "Database tablespace" : "Veritabanı tablo alanı",
    "Database host" : "Veritabanı sunucusu",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lütfen sunucu adının yanında kapı numarasını da belirtin (Örnek: localhost:5432).",
    "Performance warning" : "Başarım uyarısı",
    "You chose SQLite as database." : "Veritabanı olarak SQLite seçtiniz.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite yalnızca küçük ve geliştirme ortamları için seçilmelidir. Üretim ortamları için farklı bir veritabanı kullanmanız önerilir.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Dosya eşitlemesi için istemcileri kullanıyorsanız SQLite kullanımından kaçınmalısınız.",
    "Install" : "Kur",
    "Installing …" : "Kuruluyor…",
    "Need help?" : "Yardım gerekiyor mu?",
    "See the documentation" : "Belgelere bakın",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Nextcloud kurulumunu yeniden yapmayı deniyorsunuz gibi görünüyor. Ancak config klasöründe CAN_INSTALL dosyası eksik. Lütfen İşlemi sürdürmek için config klasöründe CAN_INSTALL dosyasını oluşturun.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Config klasöründeki CAN_INSTALL dosyası silinemedi. Lütfen bu dosyayı el ile silin.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Bu uygulamanın düzgün çalışabilmesi için JavaScript gereklidir. Lütfen {linkstart}JavaScript uygulamasını etkinleştirip{linkend} sayfayı yeniden yükleyin.",
    "Skip to main content" : "Ana içeriğe geç",
    "Skip to navigation of app" : "Uygulama gezinmesine geç",
    "Get your own free account" : "Ücretsiz hesabınızı açın",
    "%s's homepage" : "%s web sitesi",
    "Contacts" : "Kişiler",
    "Contacts menu" : "Kişiler menüsü",
    "Open settings menu" : "Ayarlar menüsünü aç",
    "Confirm your password" : "Parolanızı onaylayın",
    "Connect to your account" : "Hesabınızı bağlayın",
    "Please log in before granting %1$s access to your %2$s account." : "Lütfen %1$s için %2$s hesabınıza erişim izni vermeden önce oturum açın.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Yeni bir aygıt ya da uygulama kurmaya çalışmıyorsanız, başka biri verilerinize erişmek için sizi kandırmaya çalışıyor. Durum buysa daha ileri gitmeyin ve sistem yöneticiniz ile görüşün.",
    "App token" : "Uygulama kodu",
    "Grant access" : "Erişim izni ver",
    "Alternative log in using app token" : "Uygulama kodu ile alternatif oturum açma",
    "Account access" : "Hesap erişimi",
    "Currently logged in as %1$s (%2$s)." : "%1$s (%2$s) olarak oturum açıldı.",
    "You are about to grant %1$s access to your %2$s account." : "%1$s için %2$s hesabınıza erişim izni vermek üzeresiniz.",
    "Account connected" : "Hesap bağlandı",
    "Your client should now be connected!" : "İstemciniz şimdi bağlantı kurmuş olmalı!",
    "You can close this window." : "Bu pencereyi kapatabilirsiniz.",
    "This share is password-protected" : "Bu paylaşım parola korumalı",
    "The password is wrong or expired. Please try again or request a new one." : "Parola hatalı ya da geçerlilik süresi dolmuş. Lütfen yeniden deneyin ya da parolanızı değiştirin. ",
    "Please type in your email address to request a temporary password" : "Lütfen geçici parola isteğinde bulunmak için e-posta adresinizi yazın",
    "Email address" : "E-posta adresi",
    "Password sent!" : "Parola gönderildi!",
    "You are not authorized to request a password for this share" : "Bu paylaşım için parola isteğinde bulunma izniniz yok",
    "Go to %s" : "%s bölümüne git",
    "Two-factor authentication" : "İki aşamalı kimlik doğrulama",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Hesabınız için gelişmiş güvenlik etkinleştirildi. Kimlik doğrulaması için bir ikinci aşama seçin:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Etkinleştirilmiş iki aşamalı kimlik doğrulaması yöntemlerinden en az biri yüklenemedi. Lütfen yöneticiniz ile görüşün.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "İki aşamalı kimlik doğrulaması kullanımı zorunlu kılınmış ancak hesabınız için yapılandırılmamış. Yardım almak için sistem yöneticiniz ile görüşün.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "İki aşamalı kimlik doğrulama kullanımı dayatılmış ancak hesabınız için yapılandırılması tamamlanmamış. Lütfen işlemi sürdürmek için iki aşamalı kimlik doğrulamayı kurun.",
    "Set up two-factor authentication" : "İki aşamalı kimlik doğrulama kurulumu",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "İki aşamalı kimlik doğrulaması kullanımı zorunlu kılınmış ancak hesabınız için yapılandırılmamış. Yedek kodlarınızdan birini kullanın ya da yardım almak için sistem yöneticiniz ile görüşün.",
    "Use backup code" : "Yedek kodu kullanacağım",
    "Cancel login" : "Oturum açmaktan vazgeç",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Hesabınız için gelişmiş güvenlik kullanımı dayatılmış. Kuracağınız hizmet sağlayıcıyı seçin:",
    "Error while validating your second factor" : "İkinci aşama doğrulanırken sorun çıktı",
    "Access through untrusted domain" : "Güvenilmeyen etki alanı üzerinden erişim",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Lütfen BT yöneticiniz ile görüşün. Yöneticisi siz iseniz, config/config.php dosyası içerisindeki \"trusted_domain\" ayarını config/config.sample.php dosyasındaki gibi düzenleyin.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Bu ayar ile ilgili ayrıntılı bilgi almak için %1$sbelgelere%2$s bakabilirsiniz.",
    "App update required" : "Uygulamanın güncellenmesi gerekli",
    "%1$s will be updated to version %2$s" : "%1$s, %2$s sürümüne güncellenecek",
    "The following apps will be updated:" : "Şu uygulamalar güncellenecek:",
    "These incompatible apps will be disabled:" : "Şu uyumsuz uygulamalar devre dışı bırakılacak:",
    "The theme %s has been disabled." : "%s teması devre dışı bırakıldı.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Devam etmeden önce lütfen veritabanı, yapılandırma klasörü ve veri klasörünün yedeklenmiş olduğundan emin olun.",
    "Start update" : "Güncellemeyi başlat",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Daha büyük kurulumlarda zaman aşımlarının önüne geçmek için, kurulum klasörünüzden şu komutu da çalıştırabilirsiniz:",
    "Detailed logs" : "Ayrıntılı günlükler",
    "Update needed" : "Güncelleme gerekiyor",
    "Please use the command line updater because you have a big instance with more than 50 users." : "50 üzerinde kullanıcısı olan bir kopya kullandığınız için lütfen komut satırı güncelleyiciyi kullanın.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Yardım almak için, <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">belgelere</a> bakın.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Güncellemeyi web arayüzü üzerinden yapmanın zaman aşımına neden olarak veri kaybına neden olabileceğini biliyorum. Ancak bir yedeğim var ve sorun çıkması durumunda nasıl geri yükleyebileceğimi biliyorum.",
    "Upgrade via web on my own risk" : "Riski alıyorum web üzerinden güncelle",
    "Maintenance mode" : "Bakım kipi",
    "This %s instance is currently in maintenance mode, which may take a while." : "Bu %s kopyası şu anda bakım kipinde, bu işlem biraz zaman alabilir.",
    "This page will refresh itself when the instance is available again." : "Sistem yeniden kullanılabilir olduğunda bu sayfa kendiliğinden yenilenecek",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Bu ileti görüntülenmeye devam ediyor ya da beklenmedik şekilde ortaya çıkıyorsa BT yöneticinizle görüşün.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Kullanıcı sayısı sınırını arttırmak için abonelik anatarınızı yazın. Nextcloud Enterprise sürümü hakkında ayrıntılı bilgi almak için web sitemize bakabilirsiniz.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: %s tablosu denetleniyor",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Bu sunucunun çalışan bir İnternet bağlantısı yok. Birden çok uç noktaya erişilemez. Bu durumda dış depolama alanı bağlama, güncelleme bildirimleri ya da üçüncü taraf uygulamalarını kurmak gibi bazı özellikler çalışmaz. Dosyalara uzaktan erişim ve bildirim e-postalarının gönderilmesi işlemleri de yapılamaz. Tüm bu özelliklerin kullanılabilmesi için sunucuyu İnternet üzerine bağlamanız önerilir.",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 PHP 7.2 sürümünü destekleyen son sürümdür. Nextcloud 21 sürümü için en az PHP 7.3 gereklidir.",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "PHP OPcache modülü yüklenmemiş. {linkstart}Daa iyi başarım sağlamak için ↗{linkend} PHP kurulumunuza eklemeniz önerilir.",
    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "PHP OPcache modülü doğru şekilde ayarlanmamış. {linkstart}Daha iyi başarım sağlamak için ↗{linkend} <code>php.ini</code> dosyasında şu ayarların kullanılması önerilir:",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Veritabanında büyük tamsayıya dönüştürülecek bazı sütunlar eksik. Sütun türlerini büyük tablolara dönüştürme işlemi uzun sürebileceğinden bu işlem otomatik olarak yapılmaz. Sunucunuz normal çalışırken bekleyen değişiklikleri el ile uygulamak için \"occ db:convert-filecache-bigint\" komutunu yürütün. Bu işlem yapılırken Nextcloud kopyası çevrimdışı olur. Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Başka bir veritabanına geçmek için komut satırı aracını kullanın: 'occ db:convert-type' ya da {linkstart}belgeler ↗{linkend} bölümüne bakın.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Veri klasörünüz ve dosyalarınız İnternet üzerinden erişime açık olabilir. .htaccess dosyası çalışmıyor. Web sunucunuzu yapılandırarak veri klasörüne erişimi engellemeniz ya da veri klasörünü web sunucu kök klasörü dışına taşımanız önemle önerilir.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP üst bilgisinde \"{expected}\" bulunmuyor. Bu durum olası bir güvenlik ya da gizlilik riski oluşturduğundan bu ayarın uygun şekilde yapılması önerilir.",
    "Collaboratively edit office documents." : "Ofis belgelerini işbirlikli düzenleme.",
    "Local document editing back-end used by the Collabora Online app." : "Collabora Online uygulaması ile yerel belge düzenleme altyapısı.",
    "restricted" : "kısıtlı",
    "invisible" : "görünmez",
    "File not found" : "Dosya bulunamadı",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Belge sunucu üzerinde bulunamadı. Paylaşım silinmiş ya da geçerlilik süresi dolmuş olabilir mi?",
    "More" : "Diğer",
    "More apps menu" : "Diğer uygulamalar menüsü",
    "Settings menu" : "Ayarlar menüsü",
    "The password is wrong. Try again." : "Parola yanlış. Yeniden deneyin.",
    "Setup two-factor authentication" : "İki aşamalı kimlik doğrulama kurulumu",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Bu Nextcloud topluluk sürümü desteklenmiyor ve anlık bildirimler kullanılamıyor.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Bu Nextcloud topluluk sürümü desteklenmiyor. Bu kopyanın boyutu göz önüne alındığında, başarım, güvenilirlik ve ölçeklenebilirlik garanti edilemez. Ücretsiz hizmetimizi aşırı yüklememek için anında bildirimler devre dışı bırakıldı. nextcloud.com/enterprise adresinden Nextcloud Enterprise sürümünün avantajları hakkında ayrıntılı bilgi alabilirsiniz.",
    "You haven't added any info yet" : "Henüz herhangi bir bilgi eklememişsiniz",
    "{user} hasn't added any info yet" : "{user} henüz herhangi bir bilgi eklememiş"
},
"nplurals=2; plural=(n > 1);");
